Learn R Programming

glmmML (version 0.65-2)

glmmbootFit: Generalized Linear Models with fixed effects grouping

Description

'glmmbootFit' is the workhorse in the function glmmboot. It is suitable to call instead of 'glmmboot', e.g. in simulations.

Usage

glmmbootFit(X, Y, weights = rep(1, NROW(Y)),
start.coef = NULL, cluster = rep(1, length(Y)),
offset = rep(0, length(Y)), family = binomial(),
control = list(epsilon = 1.e-8, maxit = 200, trace
= FALSE), boot = 0)

Arguments

X
The design matrix (n * p).
Y
The response vector of length n.
weights
Case weights.
start.coef
start values for the parameters in the linear predictor (except the intercept).
cluster
Factor indicating which items are correlated.
offset
this can be used to specify an a priori known component to be included in the linear predictor during fitting.
family
Currently, the only valid values are binomial and poisson. The binomial family allows for the logit and cloglog links.
control
A list. Controls the convergence criteria. See glm.control for details.
boot
number of bootstrap replicates. If equal to zero, no test of significance of the grouping factor is performed.

Value

  • A list with components
  • coefficientsEstimated regression coefficients (note: No intercept).
  • logLikThe maximised log likelihood.
  • cluster.null.deviancedeviance from a moddel without cluster.
  • frailThe estimated cluster effects.
  • bootLogThe maximised bootstrap log likelihood values. A vector of length boot.
  • bootPThe bootstrap p value.
  • varianceThe variance-covariance matrix of the fixed effects (no intercept).
  • sdThe standard errors of the coefficients.
  • boot_repThe number of bootstrap replicates.

encoding

UTF-8

See Also

glmmboot

Examples

Run this code
## Not run
x <- matrix(rnorm(1000), ncol = 1)
id <- rep(1:100, rep(10, 100))
y <- rbinom(1000, size = 1, prob = 0.4)
fit <- glmmbootFit(x, y, cluster = id, boot = 2000)
summary(fit)
## End(Not run)
## Should show no effects.

Run the code above in your browser using DataLab